@@ -3,7 +3,7 @@ from django.contrib.auth import get_user_model
 from django.utils.translation import gettext_lazy as _
 from oauth2_provider.settings import oauth2_settings
 from django.apps import apps
-from django.conf import settings
+from mad_webhooks.settings import webhook_settings
 
 
 # Create your models here.
@@ -90,19 +90,44 @@ class Log(LogAbstract):
 ## Model methods
 def get_webhook_model():
     """Return the Webhook model that is active in this project."""
-    return apps.get_model(settings.WEBHOOK_MODEL)
+    return apps.get_model(webhook_settings.WEBHOOK_MODEL)
 
 
 def get_event_model():
     """Return the Event model that is active in this project."""
-    return apps.get_model(settings.EVENT_MODEL)
+    return apps.get_model(webhook_settings.EVENT_MODEL)
 
 
 def get_webhook_event_post_attempt_model():
     """Return the Webhook event post attempt model that is active in this project."""
-    return apps.get_model(settings.WEBHOOK_EVENT_POST_ATTEMPT_MODEL)
+    return apps.get_model(webhook_settings.WEBHOOK_EVENT_POST_ATTEMPT_MODEL)
 
 
 def get_log_model():
     """Return the Log model that is active in this project."""
-    return apps.get_model(settings.LOG_MODEL)
\ No newline at end of file
+    return apps.get_model(webhook_settings.LOG_MODEL)
+
+
+## Admin classes
+def get_webhook_admin_class():
+    """Return the Webhook admin class that is active in this project."""
+    webhook_admin_class = webhook_settings.WEBHOOK_ADMIN_CLASS
+    return webhook_admin_class
+
+
+def get_event_admin_class():
+    """Return the Event admin class that is active in this project."""
+    event_admin_class = webhook_settings.EVENT_ADMIN_CLASS
+    return event_admin_class
+
+
+def get_log_admin_class():
+    """Return the Log admin class that is active in this project."""
+    log_admin_class = webhook_settings.LOG_ADMIN_CLASS
+    return log_admin_class
+
+
+def get_webhook_event_post_attempt_admin_class():
+    """Return the Webhook event post attempt admin class that is active in this project."""
+    wepa_admin_class = webhook_settings.WEBHOOKS_WEBHOOK_EVENT_POST_ATTEMPT_ADMIN_CLASS
+    return wepa_admin_class
\ No newline at end of file
